@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005 by yodor   *
+ *   Copyright (C) 2007 by Todor Gyumyushev   *
  *   yodor@developer.bg   *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -17,79 +17,36 @@
  *   Free Software Foundation, Inc.,                                       *
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
-
 #include "knetdockapp.h"
+#include "networkdevicesdialog.h"
 
-#include <kmessagebox.h>
-#include <kpopupmenu.h>
-#include <khelpmenu.h>
-
-#include <kconfig.h>
-
-
-KNetDockApp::KNetDockApp ()
-  : KUniqueApplication (true, true, true)
+KNetDockApp::KNetDockApp() : KUniqueApplication(true,true)
 {
-	
 }
 
+
 KNetDockApp::~KNetDockApp()
 {
-	
 }
-void KNetDockApp::setAboutData(KAboutData *aboutdata)
+
+int KNetDockApp::newInstance()
 {
-	about=aboutdata;
-}
-int KNetDockApp::newInstance ()
-{
-	mydock *dock = (mydock *)mainWidget();
-	if (!dock)
+	NetworkDevicesDialog *main = (NetworkDevicesDialog *)mainWidget();
+	if (!main)
 	{
-		KConfig *cfg = new KConfig("knetdockapprc");
-		cfg->setGroup("Instances");
-		int numInstances = cfg->readNumEntry("number",1);
-		if (numInstances>16)
-		{
-			numInstances=16;
-		}
-		dock = new mydock();
-		setMainWidget(dock);		
-		KHelpMenu *mHelpMenu = new KHelpMenu( dock,about );
-		KPopupMenu *help = mHelpMenu->menu();
-		dock->contextMenu()->insertItem("&Help",help);
-		dock->start();
-		
-		
-		if (numInstances>1)
-		{
-			for (int a=1;a<numInstances;a++)
-			{
-				insertDockInstance();
-			}
-		}
-		
+		main = new NetworkDevicesDialog();
+		setMainWidget(main);		
+		//connect(this,SIGNAL(shutDown()),main,SLOT(quitAll()));
 	}
 	else
 	{
-		
-		insertDockInstance();
+		//main->restore();
+		//insertDockInstance();
 		//KMessageBox::messageBox(dock,KMessageBox::Error,"KNetDockApp is already running");
 	}
-	dock->show();
-	
+	main->setShown(true);
+	main->setWindowState(main->windowState() & ~WindowMinimized | WindowActive);
 	return 0;
 }
-void KNetDockApp::insertDockInstance()
-{
-	mydock *d = new mydock();
-		
-	d->show();
-	KHelpMenu *mHelpMenu = new KHelpMenu( d,about );
-	KPopupMenu *help = mHelpMenu->menu();
-	d->contextMenu()->insertItem("&Help",help);
-	d->contextMenu()->insertItem("&Hide", d, SLOT(hideInstance()) );
-	d->start();
-}
 
 
