@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2005 by yodor   *
- *   yodor@blackbox   *
+ *   Copyright (C) 2007 by Todor Gyumyushev   *
+ *   yodor@developer.bg   *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -17,30 +17,20 @@
  *   Free Software Foundation, Inc.,                                       *
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
-
-
-#ifndef _KNETDOCKAPP_H_
-#define _KNETDOCKAPP_H_
-
-
+#ifndef KNETDOCKAPP_H
+#define KNETDOCKAPP_H
 #include <kuniqueapplication.h>
-#include "mydock.h"
-
-
+/**
+	@author Todor Gyumyushev <yodor@developer.bg>
+*/
 class KNetDockApp : public KUniqueApplication
 {
-
 public:
-  KNetDockApp ();
-  ~KNetDockApp();
+    KNetDockApp();
+    ~KNetDockApp();
 
-  int newInstance ();
-  void setAboutData(KAboutData *about);
+	virtual int newInstance();
 
-private:
-void insertDockInstance();
-	mydock *dock;
-	KAboutData *about;
 };
-#endif // _KNETDOCKAPP_H_
 
+#endif
